@@ -104,7 +104,7 @@ def url_to_fs(url, fs_kwargs = None):
 
         return GCSFileSystem(**fs_kwargs)
     else:
-        raise ValueError(f'storage type prefix "{gs}" is not supported yet')
+        raise ValueError(f'storage type prefix "{prefix}" is not supported yet')
 
 def url_to_bucket(url):
     if '://' not in url:
@@ -115,7 +115,7 @@ def url_to_bucket(url):
     if prefix == 'gs':
         return suffix.split('/')[0]
     else:
-        raise ValueError(f'storage type prefix "{gs}" is not supported yet')
+        raise ValueError(f'storage type prefix "{prefix}" is not supported yet')
 
 # decorators
 
